@@ -58,7 +58,7 @@ class StatsNbaApi:
         self.logger = logging.getLogger('sportsdata')
 
         # Read the specification file
-        api_spec_json = json.loads(pkg_resources.read_text('', 'stats.nba.com.json'))
+        api_spec_json = json.loads(pkg_resources.read_text('sportsdata.data', 'stats.nba.com.json'))
         self.specs = json.loads(api_spec_json)
 
         self.logger.info(self.specs)
